# LiPF6 electrolyte parameters

Parameters for a LiPF6 electrolyte, from the paper

> Valøen, Lars Ole, and Jan N. Reimers. "Transport properties of LiPF6-based Li-ion battery electrolytes." Journal of The Electrochemical Society 152.5 (2005): A882-A891. [doi: 10.1149/1.1872737](http://dx.doi.org/10.1149/1.1872737)
